import 'package:composable_router/library.dart';
import 'package:example/app_router_provider.dart';
import 'package:example/routes/home_route.dart';
import 'package:example/routes/parameter_router.dart';
import 'package:flutter/widgets.dart';

class AppRouteInfoParser extends ComposableRouteInfoParser {
  AppRouteInfoParser(
    AppRouterProvider provider, {
    required BuildContext context,
  }) : super(provider, context: context);

  /// All our clean routes, clean routes are routes that do not take any parameter
  final List<ComposableRoute> cleanRoutes = [
    HomeRoute(),
  ];

  @override
  Future<ComposableRoute> parseRouteInformation(
    RouteInformation routeInformation,
  ) async {
    // If the location came in empty ignore this request
    if (routeInformation.location == null) {
      return provider.currentRoute;
    }

    // Tests all our clean routes
    for (ComposableRoute route in cleanRoutes) {
      if (routeInformation.location == route.path()) {
        return route;
      }
    }

    // Since we are not in a clean route build the uri so we can get the segments
    final uri = Uri.parse(routeInformation.location!);

    // If we failed to build the uri (should be impossible) we ignore the request
    if (uri.pathSegments.isEmpty) {
      return provider.currentRoute;
    }

    // Test the profile route
    ParameterRoute parameterRoute = ParameterRoute();
    if (uri.pathSegments[0] == parameterRoute.path().replaceAll("/", "") &&
        uri.pathSegments.length > 1) {
      parameterRoute.dummyParameter = uri.pathSegments[1];
      return parameterRoute;
    }

    // In case we can't find the specified route, we just stay on the route we where already,
    //  if this is the start of the app it will be the initial route, if you are redirecting from
    //  a loaded page this will be the current route
    return provider.currentRoute;
  }
}
