import 'package:composable_router/library.dart';
import 'package:flutter/material.dart';

/// Constructs a router with the Composable Router Delegate
class ComposableRouter<ProviderType extends ComposableRouterProvider,
        RouteInfoParserType extends ComposableRouteInfoParser>
    extends StatelessWidget {
  /// Default constructor
  const ComposableRouter({
    Key? key,
    required this.provider,
    this.routeInfoParser,
    this.routerName,
  }) : super(key: key);

  /// The router provider
  final ProviderType provider;

  /// The route info parser
  final RouteInfoParserType? routeInfoParser;

  /// The router restoration scope id
  final String? routerName;

  @override
  Widget build(BuildContext context) {
    return Router(
      restorationScopeId: routerName ?? "router",
      routerDelegate: ComposableRouterDelegate(provider, context: context),
      routeInformationParser: routeInfoParser,
      routeInformationProvider: PlatformRouteInformationProvider(
        initialRouteInformation: RouteInformation(
          location: WidgetsBinding.instance.platformDispatcher.defaultRouteName,
        ),
      ),
    );
  }
}
